import { Controller, Get, Req, Res, Next, QueryParams } from "@tsed/common";
import { Authenticate } from "@tsed/passport";
import { Configuration } from "@tsed/common";
import { Response, Request, NextFunction } from "express";

@Controller("/auth")
export class AuthController {
  @Configuration()
  private config: Configuration;

  @Get("/github")
  async githubLogin(
    @Req() req: Request,
    @Res() res: Response,
    @Next() next: NextFunction,
    @QueryParams("serviceIdentifier") serviceIdentifier: string
  ) {
    if (!serviceIdentifier) {
      res.status(400).send("serviceIdentifier is required");
      return;
    }

    // Initiate authentication with the 'state' parameter
    return Authenticate("github", {
      scope: ["user:email"],
      state: serviceIdentifier
    })(req, res, next);
  }

  @Get("/github/callback")
  @Authenticate("github", { failureRedirect: "/login" })
  async githubCallback(@Req() req: Request, @Res() res: Response) {
    // Authentication was successful
    // You can redirect the user to a specific page or return user info

    // Example: Redirect to the home page
    res.redirect("/");
  }

  @Get("/logout")
  logout(@Req() req: Request, @Res() res: Response) {
    req.logout((err) => {
      if (err) {
        return res.status(500).send("Error logging out");
      }
      res.redirect("/");
    });
  }
}
